"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ControllerRevision(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    REVISION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def data(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2.RawExtension: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    revision: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        data: kubernetes.kubernetes_io.k8s.apimachinery.pkg.runtime_pb2.RawExtension | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        revision: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["data", b"data", "metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "data", b"data", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "revision", b"revision"]) -> None: ...

global___ControllerRevision = ControllerRevision

@typing_extensions.final
class ControllerRevisionList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ControllerRevision]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ControllerRevision] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ControllerRevisionList = ControllerRevisionList

@typing_extensions.final
class DaemonSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___DaemonSetSpec: ...
    @property
    def status(self) -> global___DaemonSetStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___DaemonSetSpec | None = ...,
        status: global___DaemonSetStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___DaemonSet = DaemonSet

@typing_extensions.final
class DaemonSetCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___DaemonSetCondition = DaemonSetCondition

@typing_extensions.final
class DaemonSetList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DaemonSet]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___DaemonSet] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___DaemonSetList = DaemonSetList

@typing_extensions.final
class DaemonSetSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_READY_SECONDS_FIELD_NUMBER: builtins.int
    REVISION_HISTORY_LIMIT_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    UPDATE_STRATEGY_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    min_ready_seconds: builtins.int
    revision_history_limit: builtins.int
    @property
    def selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def template(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec: ...
    @property
    def update_strategy(self) -> global___DaemonSetUpdateStrategy: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        min_ready_seconds: builtins.int = ...,
        revision_history_limit: builtins.int = ...,
        selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        template: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec | None = ...,
        update_strategy: global___DaemonSetUpdateStrategy | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "selector", b"selector", "template", b"template", "update_strategy", b"update_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_ready_seconds", b"min_ready_seconds", "resource_info", b"resource_info", "revision_history_limit", b"revision_history_limit", "selector", b"selector", "template", b"template", "update_strategy", b"update_strategy"]) -> None: ...

global___DaemonSetSpec = DaemonSetSpec

@typing_extensions.final
class DaemonSetStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COLLISION_COUNT_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    CURRENT_NUMBER_SCHEDULED_FIELD_NUMBER: builtins.int
    DESIRED_NUMBER_SCHEDULED_FIELD_NUMBER: builtins.int
    NUMBER_AVAILABLE_FIELD_NUMBER: builtins.int
    NUMBER_MISSCHEDULED_FIELD_NUMBER: builtins.int
    NUMBER_READY_FIELD_NUMBER: builtins.int
    NUMBER_UNAVAILABLE_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    UPDATED_NUMBER_SCHEDULED_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    collision_count: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DaemonSetCondition]: ...
    current_number_scheduled: builtins.int
    desired_number_scheduled: builtins.int
    number_available: builtins.int
    number_misscheduled: builtins.int
    number_ready: builtins.int
    number_unavailable: builtins.int
    observed_generation: builtins.int
    updated_number_scheduled: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        collision_count: builtins.int = ...,
        conditions: collections.abc.Iterable[global___DaemonSetCondition] | None = ...,
        current_number_scheduled: builtins.int = ...,
        desired_number_scheduled: builtins.int = ...,
        number_available: builtins.int = ...,
        number_misscheduled: builtins.int = ...,
        number_ready: builtins.int = ...,
        number_unavailable: builtins.int = ...,
        observed_generation: builtins.int = ...,
        updated_number_scheduled: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["collision_count", b"collision_count", "conditions", b"conditions", "current_number_scheduled", b"current_number_scheduled", "desired_number_scheduled", b"desired_number_scheduled", "number_available", b"number_available", "number_misscheduled", b"number_misscheduled", "number_ready", b"number_ready", "number_unavailable", b"number_unavailable", "observed_generation", b"observed_generation", "resource_info", b"resource_info", "updated_number_scheduled", b"updated_number_scheduled"]) -> None: ...

global___DaemonSetStatus = DaemonSetStatus

@typing_extensions.final
class DaemonSetUpdateStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLLING_UPDATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def rolling_update(self) -> global___RollingUpdateDaemonSet: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        rolling_update: global___RollingUpdateDaemonSet | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update", "type", b"type"]) -> None: ...

global___DaemonSetUpdateStrategy = DaemonSetUpdateStrategy

@typing_extensions.final
class Deployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___DeploymentSpec: ...
    @property
    def status(self) -> global___DeploymentStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___DeploymentSpec | None = ...,
        status: global___DeploymentStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___Deployment = Deployment

@typing_extensions.final
class DeploymentCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    LAST_UPDATE_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def last_update_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        last_update_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "last_update_time", b"last_update_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "last_update_time", b"last_update_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___DeploymentCondition = DeploymentCondition

@typing_extensions.final
class DeploymentList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Deployment]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Deployment] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___DeploymentList = DeploymentList

@typing_extensions.final
class DeploymentSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_READY_SECONDS_FIELD_NUMBER: builtins.int
    PAUSED_FIELD_NUMBER: builtins.int
    PROGRESS_DEADLINE_SECONDS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    REVISION_HISTORY_LIMIT_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    STRATEGY_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    min_ready_seconds: builtins.int
    paused: builtins.bool
    progress_deadline_seconds: builtins.int
    replicas: builtins.int
    revision_history_limit: builtins.int
    @property
    def selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def strategy(self) -> global___DeploymentStrategy: ...
    @property
    def template(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        min_ready_seconds: builtins.int = ...,
        paused: builtins.bool = ...,
        progress_deadline_seconds: builtins.int = ...,
        replicas: builtins.int = ...,
        revision_history_limit: builtins.int = ...,
        selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        strategy: global___DeploymentStrategy | None = ...,
        template: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "selector", b"selector", "strategy", b"strategy", "template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_ready_seconds", b"min_ready_seconds", "paused", b"paused", "progress_deadline_seconds", b"progress_deadline_seconds", "replicas", b"replicas", "resource_info", b"resource_info", "revision_history_limit", b"revision_history_limit", "selector", b"selector", "strategy", b"strategy", "template", b"template"]) -> None: ...

global___DeploymentSpec = DeploymentSpec

@typing_extensions.final
class DeploymentStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABLE_REPLICAS_FIELD_NUMBER: builtins.int
    COLLISION_COUNT_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    READY_REPLICAS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    UNAVAILABLE_REPLICAS_FIELD_NUMBER: builtins.int
    UPDATED_REPLICAS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    available_replicas: builtins.int
    collision_count: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DeploymentCondition]: ...
    observed_generation: builtins.int
    ready_replicas: builtins.int
    replicas: builtins.int
    unavailable_replicas: builtins.int
    updated_replicas: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        available_replicas: builtins.int = ...,
        collision_count: builtins.int = ...,
        conditions: collections.abc.Iterable[global___DeploymentCondition] | None = ...,
        observed_generation: builtins.int = ...,
        ready_replicas: builtins.int = ...,
        replicas: builtins.int = ...,
        unavailable_replicas: builtins.int = ...,
        updated_replicas: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_replicas", b"available_replicas", "collision_count", b"collision_count", "conditions", b"conditions", "observed_generation", b"observed_generation", "ready_replicas", b"ready_replicas", "replicas", b"replicas", "resource_info", b"resource_info", "unavailable_replicas", b"unavailable_replicas", "updated_replicas", b"updated_replicas"]) -> None: ...

global___DeploymentStatus = DeploymentStatus

@typing_extensions.final
class DeploymentStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLLING_UPDATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def rolling_update(self) -> global___RollingUpdateDeployment: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        rolling_update: global___RollingUpdateDeployment | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update", "type", b"type"]) -> None: ...

global___DeploymentStrategy = DeploymentStrategy

@typing_extensions.final
class ReplicaSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___ReplicaSetSpec: ...
    @property
    def status(self) -> global___ReplicaSetStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___ReplicaSetSpec | None = ...,
        status: global___ReplicaSetStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___ReplicaSet = ReplicaSet

@typing_extensions.final
class ReplicaSetCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___ReplicaSetCondition = ReplicaSetCondition

@typing_extensions.final
class ReplicaSetList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicaSet]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___ReplicaSet] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___ReplicaSetList = ReplicaSetList

@typing_extensions.final
class ReplicaSetSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_READY_SECONDS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    min_ready_seconds: builtins.int
    replicas: builtins.int
    @property
    def selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    @property
    def template(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        min_ready_seconds: builtins.int = ...,
        replicas: builtins.int = ...,
        selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        template: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "selector", b"selector", "template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_ready_seconds", b"min_ready_seconds", "replicas", b"replicas", "resource_info", b"resource_info", "selector", b"selector", "template", b"template"]) -> None: ...

global___ReplicaSetSpec = ReplicaSetSpec

@typing_extensions.final
class ReplicaSetStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABLE_REPLICAS_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    FULLY_LABELED_REPLICAS_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    READY_REPLICAS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    available_replicas: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicaSetCondition]: ...
    fully_labeled_replicas: builtins.int
    observed_generation: builtins.int
    ready_replicas: builtins.int
    replicas: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        available_replicas: builtins.int = ...,
        conditions: collections.abc.Iterable[global___ReplicaSetCondition] | None = ...,
        fully_labeled_replicas: builtins.int = ...,
        observed_generation: builtins.int = ...,
        ready_replicas: builtins.int = ...,
        replicas: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_replicas", b"available_replicas", "conditions", b"conditions", "fully_labeled_replicas", b"fully_labeled_replicas", "observed_generation", b"observed_generation", "ready_replicas", b"ready_replicas", "replicas", b"replicas", "resource_info", b"resource_info"]) -> None: ...

global___ReplicaSetStatus = ReplicaSetStatus

@typing_extensions.final
class RollingUpdateDaemonSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_SURGE_FIELD_NUMBER: builtins.int
    MAX_UNAVAILABLE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def max_surge(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def max_unavailable(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        max_surge: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        max_unavailable: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_surge", b"max_surge", "max_unavailable", b"max_unavailable", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_surge", b"max_surge", "max_unavailable", b"max_unavailable", "resource_info", b"resource_info"]) -> None: ...

global___RollingUpdateDaemonSet = RollingUpdateDaemonSet

@typing_extensions.final
class RollingUpdateDeployment(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_SURGE_FIELD_NUMBER: builtins.int
    MAX_UNAVAILABLE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def max_surge(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def max_unavailable(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        max_surge: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        max_unavailable: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_surge", b"max_surge", "max_unavailable", b"max_unavailable", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_surge", b"max_surge", "max_unavailable", b"max_unavailable", "resource_info", b"resource_info"]) -> None: ...

global___RollingUpdateDeployment = RollingUpdateDeployment

@typing_extensions.final
class RollingUpdateStatefulSetStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_UNAVAILABLE_FIELD_NUMBER: builtins.int
    PARTITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def max_unavailable(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString: ...
    partition: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        max_unavailable: kubernetes.kubernetes_io.k8s.apimachinery.pkg.util.intstr_pb2.IntOrString | None = ...,
        partition: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["max_unavailable", b"max_unavailable", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_unavailable", b"max_unavailable", "partition", b"partition", "resource_info", b"resource_info"]) -> None: ...

global___RollingUpdateStatefulSetStrategy = RollingUpdateStatefulSetStrategy

@typing_extensions.final
class StatefulSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___StatefulSetSpec: ...
    @property
    def status(self) -> global___StatefulSetStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___StatefulSetSpec | None = ...,
        status: global___StatefulSetStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___StatefulSet = StatefulSet

@typing_extensions.final
class StatefulSetCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___StatefulSetCondition = StatefulSetCondition

@typing_extensions.final
class StatefulSetList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StatefulSet]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___StatefulSet] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___StatefulSetList = StatefulSetList

@typing_extensions.final
class StatefulSetOrdinals(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    start: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        start: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "start", b"start"]) -> None: ...

global___StatefulSetOrdinals = StatefulSetOrdinals

@typing_extensions.final
class StatefulSetPersistentVolumeClaimRetentionPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    WHEN_DELETED_FIELD_NUMBER: builtins.int
    WHEN_SCALED_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    when_deleted: builtins.str
    when_scaled: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        when_deleted: builtins.str = ...,
        when_scaled: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "when_deleted", b"when_deleted", "when_scaled", b"when_scaled"]) -> None: ...

global___StatefulSetPersistentVolumeClaimRetentionPolicy = StatefulSetPersistentVolumeClaimRetentionPolicy

@typing_extensions.final
class StatefulSetSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MIN_READY_SECONDS_FIELD_NUMBER: builtins.int
    ORDINALS_FIELD_NUMBER: builtins.int
    PERSISTENT_VOLUME_CLAIM_RETENTION_POLICY_FIELD_NUMBER: builtins.int
    POD_MANAGEMENT_POLICY_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    REVISION_HISTORY_LIMIT_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    SERVICE_NAME_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    UPDATE_STRATEGY_FIELD_NUMBER: builtins.int
    VOLUME_CLAIM_TEMPLATES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    min_ready_seconds: builtins.int
    @property
    def ordinals(self) -> global___StatefulSetOrdinals: ...
    @property
    def persistent_volume_claim_retention_policy(self) -> global___StatefulSetPersistentVolumeClaimRetentionPolicy: ...
    pod_management_policy: builtins.str
    replicas: builtins.int
    revision_history_limit: builtins.int
    @property
    def selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    service_name: builtins.str
    @property
    def template(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec: ...
    @property
    def update_strategy(self) -> global___StatefulSetUpdateStrategy: ...
    @property
    def volume_claim_templates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PersistentVolumeClaim]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        min_ready_seconds: builtins.int = ...,
        ordinals: global___StatefulSetOrdinals | None = ...,
        persistent_volume_claim_retention_policy: global___StatefulSetPersistentVolumeClaimRetentionPolicy | None = ...,
        pod_management_policy: builtins.str = ...,
        replicas: builtins.int = ...,
        revision_history_limit: builtins.int = ...,
        selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        service_name: builtins.str = ...,
        template: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec | None = ...,
        update_strategy: global___StatefulSetUpdateStrategy | None = ...,
        volume_claim_templates: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PersistentVolumeClaim] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ordinals", b"ordinals", "persistent_volume_claim_retention_policy", b"persistent_volume_claim_retention_policy", "resource_info", b"resource_info", "selector", b"selector", "template", b"template", "update_strategy", b"update_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["min_ready_seconds", b"min_ready_seconds", "ordinals", b"ordinals", "persistent_volume_claim_retention_policy", b"persistent_volume_claim_retention_policy", "pod_management_policy", b"pod_management_policy", "replicas", b"replicas", "resource_info", b"resource_info", "revision_history_limit", b"revision_history_limit", "selector", b"selector", "service_name", b"service_name", "template", b"template", "update_strategy", b"update_strategy", "volume_claim_templates", b"volume_claim_templates"]) -> None: ...

global___StatefulSetSpec = StatefulSetSpec

@typing_extensions.final
class StatefulSetStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AVAILABLE_REPLICAS_FIELD_NUMBER: builtins.int
    COLLISION_COUNT_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    CURRENT_REPLICAS_FIELD_NUMBER: builtins.int
    CURRENT_REVISION_FIELD_NUMBER: builtins.int
    OBSERVED_GENERATION_FIELD_NUMBER: builtins.int
    READY_REPLICAS_FIELD_NUMBER: builtins.int
    REPLICAS_FIELD_NUMBER: builtins.int
    UPDATE_REVISION_FIELD_NUMBER: builtins.int
    UPDATED_REPLICAS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    available_replicas: builtins.int
    collision_count: builtins.int
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StatefulSetCondition]: ...
    current_replicas: builtins.int
    current_revision: builtins.str
    observed_generation: builtins.int
    ready_replicas: builtins.int
    replicas: builtins.int
    update_revision: builtins.str
    updated_replicas: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        available_replicas: builtins.int = ...,
        collision_count: builtins.int = ...,
        conditions: collections.abc.Iterable[global___StatefulSetCondition] | None = ...,
        current_replicas: builtins.int = ...,
        current_revision: builtins.str = ...,
        observed_generation: builtins.int = ...,
        ready_replicas: builtins.int = ...,
        replicas: builtins.int = ...,
        update_revision: builtins.str = ...,
        updated_replicas: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["available_replicas", b"available_replicas", "collision_count", b"collision_count", "conditions", b"conditions", "current_replicas", b"current_replicas", "current_revision", b"current_revision", "observed_generation", b"observed_generation", "ready_replicas", b"ready_replicas", "replicas", b"replicas", "resource_info", b"resource_info", "update_revision", b"update_revision", "updated_replicas", b"updated_replicas"]) -> None: ...

global___StatefulSetStatus = StatefulSetStatus

@typing_extensions.final
class StatefulSetUpdateStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROLLING_UPDATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def rolling_update(self) -> global___RollingUpdateStatefulSetStrategy: ...
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        rolling_update: global___RollingUpdateStatefulSetStrategy | None = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rolling_update", b"rolling_update", "type", b"type"]) -> None: ...

global___StatefulSetUpdateStrategy = StatefulSetUpdateStrategy



import json
import requests
import core.sdk.helper as Helper
from models.shared.shared_pb2 import RunnerInput

class RunnerInputService:
    '''
    Provides access to the runner input data
    '''

    def fetch_runner_input(project_id: str):
        # https://devapi.oak9.cloud/console/cbalbin0625cce06/sac/proj-cbalbin0625cce06-48/runnerinput/

        if not project_id:
            return None

        url = "https://devapi.oak9.cloud/console/" + project_id.split('-')[1] + "/sac/" + project_id + "/runnerinput/"
        headers = {'Authorization': 'Bearer eyJ0eXAiOiJKV1QiLCJhbGciOiJSUzI1NiIsImtpZCI6Ilg1ZVhrNHh5b2pORnVtMWtsMll0djhkbE5QNC1jNTdkTzZRR1RWQndhTmsifQ.eyJpc3MiOiJodHRwczovL29hazlkZXYuYjJjbG9naW4uY29tLzc2ZGU0NzBjLTdhNjMtNDExZi05ODAzLTNiOWZhM2U0ZmIwYS92Mi4wLyIsImV4cCI6MTY4MDkwNzcyNywibmJmIjoxNjgwOTA0MTI3LCJhdWQiOiIyZTFmMzNlYi0yMzc0LTRiYzYtOTgyZi0yNmM1YWU4YzkzODQiLCJvaWQiOiIxODIzMWZmMS1iMDAyLTQzNWUtYWIyOC04OTkwNjI1Y2NlMDYiLCJzdWIiOiIxODIzMWZmMS1iMDAyLTQzNWUtYWIyOC04OTkwNjI1Y2NlMDYiLCJnaXZlbl9uYW1lIjoiQ2xhdWRpbyIsImZhbWlseV9uYW1lIjoiQmFsYmluIiwiZW1haWxzIjpbImNiYWxiaW5Ab2FrOS5pbyJdLCJ0ZnAiOiJCMkNfMV9TaWduSW5TaWduVXAiLCJub25jZSI6ImNGaG9SVlZPZUhoSFdUaGllRWR0UjBGUVduTlliREV5Vm5oUFltaFFUMkZ3UVdoTFRXNUVkVVUwVWtadSIsInNjcCI6ImFwaS53cml0ZSIsImF6cCI6IjIxMzdhYTRjLTVlMzUtNGE1OC04ZmQ3LWI2OWJiOGU0OTlkMyIsInZlciI6IjEuMCIsImlhdCI6MTY4MDkwNDEyN30.Xgt62eTlzd-cf1aABAprCyFlxyMTfjDwZNYKIgAzqoD7A98wZGWXj7D3jKEPPWQZb35cegEk8L4kaxk21T6vrqRyaHHMM4Gd565uinmsdSfuzAKJtuEv2LEEDFw-GQ5zOb4eQ5FLNlTsXpW1_PuClALBjJ_VOeJjSPbTk-gqRQ3fL5jAnfRhbzbItAE2ndsSVlB6MSOnAltH7hCFE-aDGAPSQizcY_Hk6lkDmPyUACCnwwrwfH19JEjaNorFpKBH4nAKGDosMTAeoSH-kgX6aFjeFU0F2qOYyRDK1mBy3x-UjO9jNbYxk97hulet7bORxFvPLnTktb9xsUQBeqkwGg'}
        response = requests.get(url, headers=headers)

        runner_input: RunnerInput = None

        raw_snake_case_input = Helper.snake_case_json(response.json())
        raw_item1 = raw_snake_case_input[0]['item1']
        for root_node in raw_item1['graph']['root_nodes']:
            root_node['node']['resource']['data']['value'] = bytes(root_node['node']['resource']['data']['value'])
        Helper.remove_attributes(raw_item1, "has_")
        runner_input = RunnerInput(**raw_item1)

        return runner_input


    def fetch_runner_input_local(request_id: str):

        if not request_id:
            return None

        runner_input: RunnerInput = None

        with open('D:\\poc\\runner_package_test\\runner_input_tython_complete.json', 'r') as file:
            raw_input = json.load(file)
            raw_snake_case_input = Helper.snake_case_json(raw_input)
            raw_item1 = raw_snake_case_input[0]['item1']
            for root_node in raw_item1['graph']['root_nodes']:
                root_node['node']['resource']['data']['value'] = bytes(root_node['node']['resource']['data']['value'])
            Helper.remove_attributes(raw_item1, "has_")
            runner_input = RunnerInput(**raw_item1)
        
        return runner_input



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_sql_servers.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'azure/azure_microsoft_sql_servers.proto\x12\'oak9.tython.azure.microsoft_sql_servers\x1a\x13shared/shared.proto\"\xf9\x0b\n\x15Microsoft_Sql_Servers\x12\x41\n\x07servers\x18\x01 \x01(\x0b\x32\x30.oak9.tython.azure.microsoft_sql_servers.Servers\x12^\n\x16servers_administrators\x18\x02 \x03(\x0b\x32>.oak9.tython.azure.microsoft_sql_servers.ServersAdministrators\x12\x63\n\x19servers_auditing_settings\x18\x03 \x01(\x0b\x32@.oak9.tython.azure.microsoft_sql_servers.ServersAuditingSettings\x12[\n\x15servers_elastic_pools\x18\x04 \x03(\x0b\x32<.oak9.tython.azure.microsoft_sql_servers.ServersElasticPools\x12i\n\x1cservers_encryption_protector\x18\x05 \x01(\x0b\x32\x43.oak9.tython.azure.microsoft_sql_servers.ServersEncryptionProtector\x12t\n\"servers_extended_auditing_settings\x18\x06 \x01(\x0b\x32H.oak9.tython.azure.microsoft_sql_servers.ServersExtendedAuditingSettings\x12_\n\x17servers_failover_groups\x18\x07 \x03(\x0b\x32>.oak9.tython.azure.microsoft_sql_servers.ServersFailoverGroups\x12]\n\x16servers_firewall_rules\x18\x08 \x03(\x0b\x32=.oak9.tython.azure.microsoft_sql_servers.ServersFirewallRules\x12U\n\x12servers_job_agents\x18\t \x03(\x0b\x32\x39.oak9.tython.azure.microsoft_sql_servers.ServersJobAgents\x12l\n\x1eservers_job_agents_credentials\x18\n \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_sql_servers.ServersJobAgentsCredentials\x12J\n\x0cservers_keys\x18\x0b \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_sql_servers.ServersKeys\x12x\n$servers_private_endpoint_connections\x18\x0c \x03(\x0b\x32J.oak9.tython.azure.microsoft_sql_servers.ServersPrivateEndpointConnections\x12n\n\x1fservers_security_alert_policies\x18\r \x01(\x0b\x32\x45.oak9.tython.azure.microsoft_sql_servers.ServersSecurityAlertPolicies\x12j\n\x1dservers_virtual_network_rules\x18\x0e \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_sql_servers.ServersVirtualNetworkRules\x12s\n!servers_vulnerability_assessments\x18\x0f \x01(\x0b\x32H.oak9.tython.azure.microsoft_sql_servers.ServersVulnerabilityAssessments\"\xc2\x02\n\x1fServersVulnerabilityAssessments\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12q\n\x0frecurring_scans\x18\x03 \x01(\x0b\x32X.oak9.tython.azure.microsoft_sql_servers.VulnerabilityAssessmentRecurringScansProperties\x12\"\n\x1astorage_account_access_key\x18\x04 \x01(\t\x12\x1e\n\x16storage_container_path\x18\x05 \x01(\t\x12!\n\x19storage_container_sas_key\x18\x06 \x01(\t\"x\n/VulnerabilityAssessmentRecurringScansProperties\x12\x0e\n\x06\x65mails\x18\x01 \x03(\t\x12!\n\x19\x65mail_subscription_admins\x18\x02 \x01(\x08\x12\x12\n\nis_enabled\x18\x03 \x01(\x08\"\xb4\x01\n\x1aServersVirtualNetworkRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12,\n$ignore_missing_vnet_service_endpoint\x18\x03 \x01(\x08\x12!\n\x19virtual_network_subnet_id\x18\x04 \x01(\t\"t\n\x11ServersSyncAgents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10sync_database_id\x18\x03 \x01(\t\"\x9a\x02\n\x1cServersSecurityAlertPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0f\x64isabled_alerts\x18\x03 \x03(\t\x12\x1c\n\x14\x65mail_account_admins\x18\x04 \x01(\x08\x12\x17\n\x0f\x65mail_addresses\x18\x05 \x03(\t\x12\x16\n\x0eretention_days\x18\x06 \x01(\x05\x12\r\n\x05state\x18\x07 \x01(\t\x12\"\n\x1astorage_account_access_key\x18\x08 \x01(\t\x12\x18\n\x10storage_endpoint\x18\t \x01(\t\"\xca\x02\n!ServersPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Z\n\x10private_endpoint\x18\x03 \x01(\x0b\x32@.oak9.tython.azure.microsoft_sql_servers.PrivateEndpointProperty\x12\x81\x01\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32R.oak9.tython.azure.microsoft_sql_servers.PrivateLinkServiceConnectionStateProperty\"P\n)PrivateLinkServiceConnectionStateProperty\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\t\"%\n\x17PrivateEndpointProperty\x12\n\n\x02id\x18\x01 \x01(\t\"e\n\x1cServersOutboundFirewallRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xb3\x01\n\x0bServersKeys\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0fserver_key_type\x18\x03 \x01(\t\x12\x0b\n\x03uri\x18\x04 \x01(\t\x12\x12\n\nthumbprint\x18\x05 \x01(\t\x12\x15\n\rcreation_date\x18\x06 \x01(\t\x12\x0c\n\x04kind\x18\x07 \x01(\t\"\xaa\x01\n\x1cServersJobAgentsTargetGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x43\n\x07members\x18\x03 \x03(\x0b\x32\x32.oak9.tython.azure.microsoft_sql_servers.JobTarget\"\xad\x01\n\tJobTarget\x12\x15\n\rdatabase_name\x18\x01 \x01(\t\x12\x19\n\x11\x65lastic_pool_name\x18\x02 \x01(\t\x12\x17\n\x0fmembership_type\x18\x03 \x01(\t\x12\x1a\n\x12refresh_credential\x18\x04 \x01(\t\x12\x13\n\x0bserver_name\x18\x05 \x01(\t\x12\x16\n\x0eshard_map_name\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\t\"\x8a\x03\n\x19ServersJobAgentsJobsSteps\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x46\n\x06\x61\x63tion\x18\x03 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_sql_servers.JobStepAction\x12\x12\n\ncredential\x18\x04 \x01(\t\x12[\n\x11\x65xecution_options\x18\x05 \x01(\x0b\x32@.oak9.tython.azure.microsoft_sql_servers.JobStepExecutionOptions\x12\x46\n\x06output\x18\x06 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_sql_servers.JobStepOutput\x12\x0f\n\x07step_id\x18\x07 \x01(\x05\x12\x14\n\x0ctarget_group\x18\x08 \x01(\t\"\xbc\x01\n\rJobStepOutput\x12\x12\n\ncredential\x18\x01 \x01(\t\x12\x15\n\rdatabase_name\x18\x02 \x01(\t\x12\x1b\n\x13resource_group_name\x18\x03 \x01(\t\x12\x13\n\x0bschema_name\x18\x04 \x01(\t\x12\x13\n\x0bserver_name\x18\x05 \x01(\t\x12\x17\n\x0fsubscription_id\x18\x06 \x01(\t\x12\x12\n\ntable_name\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\"\xc5\x01\n\x17JobStepExecutionOptions\x12&\n\x1einitial_retry_interval_seconds\x18\x01 \x01(\x05\x12&\n\x1emaximum_retry_interval_seconds\x18\x02 \x01(\x05\x12\x16\n\x0eretry_attempts\x18\x03 \x01(\x05\x12)\n!retry_interval_backoff_multiplier\x18\x04 \x01(\x01\x12\x17\n\x0ftimeout_seconds\x18\x05 \x01(\x05\"<\n\rJobStepAction\x12\x0e\n\x06source\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"g\n\x1eServersJobAgentsJobsExecutions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x9a\x03\n\x14ServersJobAgentsJobs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x46\n\x08schedule\x18\x04 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_sql_servers.JobSchedule\x12s\n\"servers_job_agents_jobs_executions\x18\x05 \x03(\x0b\x32G.oak9.tython.azure.microsoft_sql_servers.ServersJobAgentsJobsExecutions\x12i\n\x1dservers_job_agents_jobs_steps\x18\x06 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_sql_servers.ServersJobAgentsJobsSteps\"d\n\x0bJobSchedule\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\x12\x10\n\x08\x65nd_time\x18\x02 \x01(\t\x12\x10\n\x08interval\x18\x03 \x01(\t\x12\x12\n\nstart_time\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\"\x88\x01\n\x1bServersJobAgentsCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x10\n\x08username\x18\x04 \x01(\t\"\x8c\x04\n\x10ServersJobAgents\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x61tabase_id\x18\x04 \x01(\t\x12\x39\n\x03sku\x18\x05 \x01(\x0b\x32,.oak9.tython.azure.microsoft_sql_servers.Sku\x12Q\n\x04tags\x18\x06 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_sql_servers.ServersJobAgents.TagsEntry\x12^\n\x17servers_job_agents_jobs\x18\x07 \x03(\x0b\x32=.oak9.tython.azure.microsoft_sql_servers.ServersJobAgentsJobs\x12o\n servers_job_agents_target_groups\x18\x08 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_sql_servers.ServersJobAgentsTargetGroups\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n\x18ServersIpv6FirewallRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x18\n\x10\x65nd_ipv6_address\x18\x03 \x01(\t\x12\x1a\n\x12start_ipv6_address\x18\x04 \x01(\t\"\x8f\x01\n\x14ServersFirewallRules\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0e\x65nd_ip_address\x18\x03 \x01(\t\x12\x18\n\x10start_ip_address\x18\x04 \x01(\t\"\x8f\x04\n\x15ServersFailoverGroups\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tdatabases\x18\x03 \x03(\t\x12M\n\x0fpartner_servers\x18\x04 \x03(\x0b\x32\x34.oak9.tython.azure.microsoft_sql_servers.PartnerInfo\x12\x62\n\x12read_only_endpoint\x18\x05 \x01(\x0b\x32\x46.oak9.tython.azure.microsoft_sql_servers.FailoverGroupReadOnlyEndpoint\x12\x64\n\x13read_write_endpoint\x18\x06 \x01(\x0b\x32G.oak9.tython.azure.microsoft_sql_servers.FailoverGroupReadWriteEndpoint\x12V\n\x04tags\x18\x07 \x03(\x0b\x32H.oak9.tython.azure.microsoft_sql_servers.ServersFailoverGroups.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"o\n\x1e\x46\x61iloverGroupReadWriteEndpoint\x12\x17\n\x0f\x66\x61ilover_policy\x18\x01 \x01(\t\x12\x34\n,failover_with_data_loss_grace_period_minutes\x18\x02 \x01(\x05\"8\n\x1d\x46\x61iloverGroupReadOnlyEndpoint\x12\x17\n\x0f\x66\x61ilover_policy\x18\x01 \x01(\t\"\x19\n\x0bPartnerInfo\x12\n\n\x02id\x18\x01 \x01(\t\"\xc1\x03\n\x1fServersExtendedAuditingSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x18\x61udit_actions_and_groups\x18\x03 \x03(\t\x12\'\n\x1fis_azure_monitor_target_enabled\x18\x04 \x01(\x08\x12\x1f\n\x17is_devops_audit_enabled\x18\x05 \x01(\x08\x12\'\n\x1fis_storage_secondary_key_in_use\x18\x06 \x01(\x08\x12\x1c\n\x14predicate_expression\x18\x07 \x01(\t\x12\x16\n\x0equeue_delay_ms\x18\x08 \x01(\x05\x12\x16\n\x0eretention_days\x18\t \x01(\x05\x12\r\n\x05state\x18\n \x01(\t\x12\"\n\x1astorage_account_access_key\x18\x0b \x01(\t\x12\'\n\x1fstorage_account_subscription_id\x18\x0c \x01(\t\x12\x18\n\x10storage_endpoint\x18\r \x01(\t\"\xb4\x01\n\x1aServersEncryptionProtector\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1d\n\x15\x61uto_rotation_enabled\x18\x03 \x01(\x08\x12\x17\n\x0fserver_key_name\x18\x04 \x01(\t\x12\x17\n\x0fserver_key_type\x18\x05 \x01(\t\"\xa9\x04\n\x13ServersElasticPools\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\'\n\x1fhigh_availability_replica_count\x18\x04 \x01(\x05\x12\x14\n\x0clicense_type\x18\x05 \x01(\t\x12$\n\x1cmaintenance_configuration_id\x18\x06 \x01(\t\x12\x16\n\x0emax_size_bytes\x18\x07 \x01(\x05\x12\x66\n\x15per_database_settings\x18\x08 \x01(\x0b\x32G.oak9.tython.azure.microsoft_sql_servers.ElasticPoolPerDatabaseSettings\x12\x16\n\x0ezone_redundant\x18\t \x01(\x08\x12\x39\n\x03sku\x18\n \x01(\x0b\x32,.oak9.tython.azure.microsoft_sql_servers.Sku\x12T\n\x04tags\x18\x0b \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_sql_servers.ServersElasticPools.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Q\n\x03Sku\x12\x10\n\x08\x63\x61pacity\x18\x01 \x01(\x05\x12\x0e\n\x06\x66\x61mily\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04size\x18\x04 \x01(\t\x12\x0c\n\x04tier\x18\x05 \x01(\t\"L\n\x1e\x45lasticPoolPerDatabaseSettings\x12\x14\n\x0cmax_capacity\x18\x01 \x01(\x01\x12\x14\n\x0cmin_capacity\x18\x02 \x01(\x01\"Z\n\x11ServersDnsAliases\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x85\x02\n\x1dServersDevOpsAuditingSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\'\n\x1fis_azure_monitor_target_enabled\x18\x03 \x01(\x08\x12\r\n\x05state\x18\x04 \x01(\t\x12\"\n\x1astorage_account_access_key\x18\x05 \x01(\t\x12\'\n\x1fstorage_account_subscription_id\x18\x06 \x01(\t\x12\x18\n\x10storage_endpoint\x18\x07 \x01(\t\"{\n\x19ServersConnectionPolicies\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x03 \x01(\t\"\x90\x01\n!ServersAzureADOnlyAuthentications\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12$\n\x1c\x61zure_ad_only_authentication\x18\x03 \x01(\x08\"\x9b\x03\n\x17ServersAuditingSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12 \n\x18\x61udit_actions_and_groups\x18\x03 \x03(\t\x12\'\n\x1fis_azure_monitor_target_enabled\x18\x04 \x01(\x08\x12\x1f\n\x17is_devops_audit_enabled\x18\x05 \x01(\x08\x12\'\n\x1fis_storage_secondary_key_in_use\x18\x06 \x01(\x08\x12\x16\n\x0equeue_delay_ms\x18\x07 \x01(\x05\x12\x16\n\x0eretention_days\x18\x08 \x01(\x05\x12\r\n\x05state\x18\t \x01(\t\x12\"\n\x1astorage_account_access_key\x18\n \x01(\t\x12\'\n\x1fstorage_account_subscription_id\x18\x0b \x01(\t\x12\x18\n\x10storage_endpoint\x18\x0c \x01(\t\"\xcf\x01\n\x15ServersAdministrators\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1a\n\x12\x61\x64ministrator_type\x18\x03 \x01(\t\x12\r\n\x05login\x18\x04 \x01(\t\x12\x0b\n\x03sid\x18\x05 \x01(\t\x12\x11\n\ttenant_id\x18\x06 \x01(\t\x12$\n\x1c\x61zure_ad_only_authentication\x18\x07 \x01(\t\"\xf7\n\n\x07Servers\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x08identity\x18\x02 \x01(\x0b\x32\x39.oak9.tython.azure.microsoft_sql_servers.ResourceIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1b\n\x13\x61\x64ministrator_login\x18\x05 \x01(\t\x12$\n\x1c\x61\x64ministrator_login_password\x18\x06 \x01(\t\x12\\\n\x0e\x61\x64ministrators\x18\x07 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_sql_servers.ServerExternalAdministrator\x12\x1b\n\x13\x66\x65\x64\x65rated_client_id\x18\x08 \x01(\t\x12\x0e\n\x06key_id\x18\t \x01(\t\x12\x1b\n\x13minimal_tls_version\x18\n \x01(\t\x12)\n!primary_user_assigned_identity_id\x18\x0b \x01(\t\x12\x1d\n\x15public_network_access\x18\x0c \x01(\t\x12(\n restrict_outbound_network_access\x18\r \x01(\t\x12\x0f\n\x07version\x18\x0e \x01(\t\x12H\n\x04tags\x18\x0f \x03(\x0b\x32:.oak9.tython.azure.microsoft_sql_servers.Servers.TagsEntry\x12\x66\n\x1bservers_ipv6_firewall_rules\x18\x10 \x03(\x0b\x32\x41.oak9.tython.azure.microsoft_sql_servers.ServersIpv6FirewallRules\x12n\n\x1fservers_outbound_firewall_rules\x18\x11 \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_sql_servers.ServersOutboundFirewallRules\x12y\n%servers_azure_ad_only_authentications\x18\x12 \x03(\x0b\x32J.oak9.tython.azure.microsoft_sql_servers.ServersAzureADOnlyAuthentications\x12g\n\x1bservers_connection_policies\x18\x13 \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_sql_servers.ServersConnectionPolicies\x12q\n!servers_dev_ops_auditing_settings\x18\x14 \x03(\x0b\x32\x46.oak9.tython.azure.microsoft_sql_servers.ServersDevOpsAuditingSettings\x12W\n\x13servers_dns_aliases\x18\x15 \x03(\x0b\x32:.oak9.tython.azure.microsoft_sql_servers.ServersDnsAliases\x12W\n\x13servers_sync_agents\x18\x16 \x03(\x0b\x32:.oak9.tython.azure.microsoft_sql_servers.ServersSyncAgents\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa6\x01\n\x1bServerExternalAdministrator\x12\x1a\n\x12\x61\x64ministrator_type\x18\x01 \x01(\t\x12$\n\x1c\x61zure_ad_only_authentication\x18\x02 \x01(\x08\x12\r\n\x05login\x18\x03 \x01(\t\x12\x16\n\x0eprincipal_type\x18\x04 \x01(\t\x12\x0b\n\x03sid\x18\x05 \x01(\t\x12\x11\n\ttenant_id\x18\x06 \x01(\t\"\xd8\x01\n\x10ResourceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12w\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32U.oak9.tython.azure.microsoft_sql_servers.ResourceIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_sql_servers_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SERVERSJOBAGENTS_TAGSENTRY._options = None
  _SERVERSJOBAGENTS_TAGSENTRY._serialized_options = b'8\001'
  _SERVERSFAILOVERGROUPS_TAGSENTRY._options = None
  _SERVERSFAILOVERGROUPS_TAGSENTRY._serialized_options = b'8\001'
  _SERVERSELASTICPOOLS_TAGSENTRY._options = None
  _SERVERSELASTICPOOLS_TAGSENTRY._serialized_options = b'8\001'
  _SERVERS_TAGSENTRY._options = None
  _SERVERS_TAGSENTRY._serialized_options = b'8\001'
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _MICROSOFT_SQL_SERVERS._serialized_start=106
  _MICROSOFT_SQL_SERVERS._serialized_end=1635
  _SERVERSVULNERABILITYASSESSMENTS._serialized_start=1638
  _SERVERSVULNERABILITYASSESSMENTS._serialized_end=1960
  _VULNERABILITYASSESSMENTRECURRINGSCANSPROPERTIES._serialized_start=1962
  _VULNERABILITYASSESSMENTRECURRINGSCANSPROPERTIES._serialized_end=2082
  _SERVERSVIRTUALNETWORKRULES._serialized_start=2085
  _SERVERSVIRTUALNETWORKRULES._serialized_end=2265
  _SERVERSSYNCAGENTS._serialized_start=2267
  _SERVERSSYNCAGENTS._serialized_end=2383
  _SERVERSSECURITYALERTPOLICIES._serialized_start=2386
  _SERVERSSECURITYALERTPOLICIES._serialized_end=2668
  _SERVERSPRIVATEENDPOINTCONNECTIONS._serialized_start=2671
  _SERVERSPRIVATEENDPOINTCONNECTIONS._serialized_end=3001
  _PRIVATELINKSERVICECONNECTIONSTATEPROPERTY._serialized_start=3003
  _PRIVATELINKSERVICECONNECTIONSTATEPROPERTY._serialized_end=3083
  _PRIVATEENDPOINTPROPERTY._serialized_start=3085
  _PRIVATEENDPOINTPROPERTY._serialized_end=3122
  _SERVERSOUTBOUNDFIREWALLRULES._serialized_start=3124
  _SERVERSOUTBOUNDFIREWALLRULES._serialized_end=3225
  _SERVERSKEYS._serialized_start=3228
  _SERVERSKEYS._serialized_end=3407
  _SERVERSJOBAGENTSTARGETGROUPS._serialized_start=3410
  _SERVERSJOBAGENTSTARGETGROUPS._serialized_end=3580
  _JOBTARGET._serialized_start=3583
  _JOBTARGET._serialized_end=3756
  _SERVERSJOBAGENTSJOBSSTEPS._serialized_start=3759
  _SERVERSJOBAGENTSJOBSSTEPS._serialized_end=4153
  _JOBSTEPOUTPUT._serialized_start=4156
  _JOBSTEPOUTPUT._serialized_end=4344
  _JOBSTEPEXECUTIONOPTIONS._serialized_start=4347
  _JOBSTEPEXECUTIONOPTIONS._serialized_end=4544
  _JOBSTEPACTION._serialized_start=4546
  _JOBSTEPACTION._serialized_end=4606
  _SERVERSJOBAGENTSJOBSEXECUTIONS._serialized_start=4608
  _SERVERSJOBAGENTSJOBSEXECUTIONS._serialized_end=4711
  _SERVERSJOBAGENTSJOBS._serialized_start=4714
  _SERVERSJOBAGENTSJOBS._serialized_end=5124
  _JOBSCHEDULE._serialized_start=5126
  _JOBSCHEDULE._serialized_end=5226
  _SERVERSJOBAGENTSCREDENTIALS._serialized_start=5229
  _SERVERSJOBAGENTSCREDENTIALS._serialized_end=5365
  _SERVERSJOBAGENTS._serialized_start=5368
  _SERVERSJOBAGENTS._serialized_end=5892
  _SERVERSJOBAGENTS_TAGSENTRY._serialized_start=5849
  _SERVERSJOBAGENTS_TAGSENTRY._serialized_end=5892
  _SERVERSIPV6FIREWALLRULES._serialized_start=5895
  _SERVERSIPV6FIREWALLRULES._serialized_end=6046
  _SERVERSFIREWALLRULES._serialized_start=6049
  _SERVERSFIREWALLRULES._serialized_end=6192
  _SERVERSFAILOVERGROUPS._serialized_start=6195
  _SERVERSFAILOVERGROUPS._serialized_end=6722
  _SERVERSFAILOVERGROUPS_TAGSENTRY._serialized_start=5849
  _SERVERSFAILOVERGROUPS_TAGSENTRY._serialized_end=5892
  _FAILOVERGROUPREADWRITEENDPOINT._serialized_start=6724
  _FAILOVERGROUPREADWRITEENDPOINT._serialized_end=6835
  _FAILOVERGROUPREADONLYENDPOINT._serialized_start=6837
  _FAILOVERGROUPREADONLYENDPOINT._serialized_end=6893
  _PARTNERINFO._serialized_start=6895
  _PARTNERINFO._serialized_end=6920
  _SERVERSEXTENDEDAUDITINGSETTINGS._serialized_start=6923
  _SERVERSEXTENDEDAUDITINGSETTINGS._serialized_end=7372
  _SERVERSENCRYPTIONPROTECTOR._serialized_start=7375
  _SERVERSENCRYPTIONPROTECTOR._serialized_end=7555
  _SERVERSELASTICPOOLS._serialized_start=7558
  _SERVERSELASTICPOOLS._serialized_end=8111
  _SERVERSELASTICPOOLS_TAGSENTRY._serialized_start=5849
  _SERVERSELASTICPOOLS_TAGSENTRY._serialized_end=5892
  _SKU._serialized_start=8113
  _SKU._serialized_end=8194
  _ELASTICPOOLPERDATABASESETTINGS._serialized_start=8196
  _ELASTICPOOLPERDATABASESETTINGS._serialized_end=8272
  _SERVERSDNSALIASES._serialized_start=8274
  _SERVERSDNSALIASES._serialized_end=8364
  _SERVERSDEVOPSAUDITINGSETTINGS._serialized_start=8367
  _SERVERSDEVOPSAUDITINGSETTINGS._serialized_end=8628
  _SERVERSCONNECTIONPOLICIES._serialized_start=8630
  _SERVERSCONNECTIONPOLICIES._serialized_end=8753
  _SERVERSAZUREADONLYAUTHENTICATIONS._serialized_start=8756
  _SERVERSAZUREADONLYAUTHENTICATIONS._serialized_end=8900
  _SERVERSAUDITINGSETTINGS._serialized_start=8903
  _SERVERSAUDITINGSETTINGS._serialized_end=9314
  _SERVERSADMINISTRATORS._serialized_start=9317
  _SERVERSADMINISTRATORS._serialized_end=9524
  _SERVERS._serialized_start=9527
  _SERVERS._serialized_end=10926
  _SERVERS_TAGSENTRY._serialized_start=5849
  _SERVERS_TAGSENTRY._serialized_end=5892
  _SERVEREXTERNALADMINISTRATOR._serialized_start=10929
  _SERVEREXTERNALADMINISTRATOR._serialized_end=11095
  _RESOURCEIDENTITY._serialized_start=11098
  _RESOURCEIDENTITY._serialized_end=11314
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=11253
  _RESOURCEIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=11314
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.autoscaling.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5kubernetes/kubernetes_io.k8s.api.autoscaling.v1.proto\x12\"oak9.tython.k8s.api.autoscaling.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\"\x87\x01\n\x1b\x43rossVersionObjectReference\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe4\x02\n\x17HorizontalPodAutoscaler\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12M\n\x04spec\x18\x04 \x01(\x0b\x32?.oak9.tython.k8s.api.autoscaling.v1.HorizontalPodAutoscalerSpec\x12Q\n\x06status\x18\x05 \x01(\x0b\x32\x41.oak9.tython.k8s.api.autoscaling.v1.HorizontalPodAutoscalerStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x90\x02\n\x1bHorizontalPodAutoscalerList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12J\n\x05items\x18\x02 \x03(\x0b\x32;.oak9.tython.k8s.api.autoscaling.v1.HorizontalPodAutoscaler\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x88\x02\n\x1bHorizontalPodAutoscalerSpec\x12\x14\n\x0cmax_replicas\x18\x01 \x01(\x05\x12\x14\n\x0cmin_replicas\x18\x02 \x01(\x05\x12Y\n\x10scale_target_ref\x18\x03 \x01(\x0b\x32?.oak9.tython.k8s.api.autoscaling.v1.CrossVersionObjectReference\x12)\n!target_cpu_utilization_percentage\x18\x04 \x01(\x05\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa3\x02\n\x1dHorizontalPodAutoscalerStatus\x12*\n\"current_cpu_utilization_percentage\x18\x01 \x01(\x05\x12\x18\n\x10\x63urrent_replicas\x18\x02 \x01(\x05\x12\x18\n\x10\x64\x65sired_replicas\x18\x03 \x01(\x05\x12L\n\x0flast_scale_time\x18\x04 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x1b\n\x13observed_generation\x18\x05 \x01(\x05\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xae\x02\n\x05Scale\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12;\n\x04spec\x18\x04 \x01(\x0b\x32-.oak9.tython.k8s.api.autoscaling.v1.ScaleSpec\x12?\n\x06status\x18\x05 \x01(\x0b\x32/.oak9.tython.k8s.api.autoscaling.v1.ScaleStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"V\n\tScaleSpec\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"j\n\x0bScaleStatus\x12\x10\n\x08replicas\x18\x01 \x01(\x05\x12\x10\n\x08selector\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.autoscaling.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CROSSVERSIONOBJECTREFERENCE._serialized_start=181
  _CROSSVERSIONOBJECTREFERENCE._serialized_end=316
  _HORIZONTALPODAUTOSCALER._serialized_start=319
  _HORIZONTALPODAUTOSCALER._serialized_end=675
  _HORIZONTALPODAUTOSCALERLIST._serialized_start=678
  _HORIZONTALPODAUTOSCALERLIST._serialized_end=950
  _HORIZONTALPODAUTOSCALERSPEC._serialized_start=953
  _HORIZONTALPODAUTOSCALERSPEC._serialized_end=1217
  _HORIZONTALPODAUTOSCALERSTATUS._serialized_start=1220
  _HORIZONTALPODAUTOSCALERSTATUS._serialized_end=1511
  _SCALE._serialized_start=1514
  _SCALE._serialized_end=1816
  _SCALESPEC._serialized_start=1818
  _SCALESPEC._serialized_end=1904
  _SCALESTATUS._serialized_start=1906
  _SCALESTATUS._serialized_end=2012
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeHaVpnGatewayXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeHaVpnGatewayXTimeouts = ComputeHaVpnGatewayXTimeouts

@typing_extensions.final
class ComputeHaVpnGatewayXVpnInterfaces(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    INTERCONNECT_ATTACHMENT_FIELD_NUMBER: builtins.int
    IP_ADDRESS_FIELD_NUMBER: builtins.int
    id: builtins.float
    interconnect_attachment: builtins.str
    ip_address: builtins.str
    def __init__(
        self,
        *,
        id: builtins.float = ...,
        interconnect_attachment: builtins.str = ...,
        ip_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "interconnect_attachment", b"interconnect_attachment", "ip_address", b"ip_address"]) -> None: ...

global___ComputeHaVpnGatewayXVpnInterfaces = ComputeHaVpnGatewayXVpnInterfaces

@typing_extensions.final
class ComputeHaVpnGateway(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    VPN_INTERFACES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    description: builtins.str
    id: builtins.str
    name: builtins.str
    network: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    @property
    def timeouts(self) -> global___ComputeHaVpnGatewayXTimeouts: ...
    @property
    def vpn_interfaces(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ComputeHaVpnGatewayXVpnInterfaces]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        timeouts: global___ComputeHaVpnGatewayXTimeouts | None = ...,
        vpn_interfaces: collections.abc.Iterable[global___ComputeHaVpnGatewayXVpnInterfaces] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "id", b"id", "name", b"name", "network", b"network", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "timeouts", b"timeouts", "vpn_interfaces", b"vpn_interfaces"]) -> None: ...

global___ComputeHaVpnGateway = ComputeHaVpnGateway



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class VpcAccessConnectorXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___VpcAccessConnectorXTimeouts = VpcAccessConnectorXTimeouts

@typing_extensions.final
class VpcAccessConnector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    IP_CIDR_RANGE_FIELD_NUMBER: builtins.int
    MAX_THROUGHPUT_FIELD_NUMBER: builtins.int
    MIN_THROUGHPUT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NETWORK_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    ip_cidr_range: builtins.str
    max_throughput: builtins.float
    min_throughput: builtins.float
    name: builtins.str
    network: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    state: builtins.str
    @property
    def timeouts(self) -> global___VpcAccessConnectorXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        ip_cidr_range: builtins.str = ...,
        max_throughput: builtins.float = ...,
        min_throughput: builtins.float = ...,
        name: builtins.str = ...,
        network: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        state: builtins.str = ...,
        timeouts: global___VpcAccessConnectorXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "ip_cidr_range", b"ip_cidr_range", "max_throughput", b"max_throughput", "min_throughput", b"min_throughput", "name", b"name", "network", b"network", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "state", b"state", "timeouts", b"timeouts"]) -> None: ...

global___VpcAccessConnector = VpcAccessConnector
